"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, delivery_channel_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the delivery channel. Before you can delete the delivery channel, you must stop the configuration recorder by using the StopConfigurationRecorder action.

    Args:
        delivery_channel_name(str): The name of the delivery channel to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.delivery_channel.init.delete(
                ctx, delivery_channel_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.delivery_channel.init.delete delivery_channel_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="delete_delivery_channel",
        op_kwargs={"DeliveryChannelName": delivery_channel_name},
    )


async def describe_all(hub, ctx, delivery_channel_names: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns details about the specified delivery channel. If a delivery channel is not specified, this action returns the details of all delivery channels associated with the account.  Currently, you can specify only one delivery channel per region in your account.

    Args:
        delivery_channel_names(List, optional): A list of delivery channel names. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.delivery_channel.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.delivery_channel.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_delivery_channels",
        op_kwargs={"DeliveryChannelNames": delivery_channel_names},
    )


async def put(hub, ctx, delivery_channel: Dict) -> None:
    r"""
    **Autogenerated function**

    Creates a delivery channel object to deliver configuration information to an Amazon S3 bucket and Amazon SNS topic. Before you can create a delivery channel, you must create a configuration recorder. You can use this action to change the Amazon S3 bucket or an Amazon SNS topic of the existing delivery channel. To change the Amazon S3 bucket or an Amazon SNS topic, call this action and specify the changed values for the S3 bucket and the SNS topic. If you specify a different value for either the S3 bucket or the SNS topic, this action will keep the existing value for the parameter that is not changed.  You can have only one delivery channel per region in your account.

    Args:
        delivery_channel(Dict): The configuration delivery channel object that delivers the configuration information to an Amazon S3 bucket and to an Amazon SNS topic.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.delivery_channel.init.put(ctx, delivery_channel=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.delivery_channel.init.put delivery_channel=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="put_delivery_channel",
        op_kwargs={"DeliveryChannel": delivery_channel},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, config_id: str, account_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the Amazon S3 Storage Lens configuration. For more information about S3 Storage Lens, see Assessing your storage activity and usage with Amazon S3 Storage Lens  in the Amazon S3 User Guide.  To use this action, you must have permission to perform the s3:DeleteStorageLensConfiguration action. For more information, see Setting permissions to use Amazon S3 Storage Lens in the Amazon S3 User Guide.

    Args:
        config_id(str): The ID of the S3 Storage Lens configuration.
        account_id(str): The account ID of the requester.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.storage_lens_configuration.init.delete(
                ctx, config_id=value, account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.storage_lens_configuration.init.delete config_id=value, account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="delete_storage_lens_configuration",
        op_kwargs={"ConfigId": config_id, "AccountId": account_id},
    )


async def get(hub, ctx, config_id: str, account_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the Amazon S3 Storage Lens configuration. For more information, see Assessing your storage activity and usage with Amazon S3 Storage Lens  in the Amazon S3 User Guide.  To use this action, you must have permission to perform the s3:GetStorageLensConfiguration action. For more information, see Setting permissions to use Amazon S3 Storage Lens in the Amazon S3 User Guide.

    Args:
        config_id(str): The ID of the Amazon S3 Storage Lens configuration.
        account_id(str): The account ID of the requester.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.storage_lens_configuration.init.get(
                ctx, config_id=value, account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.storage_lens_configuration.init.get config_id=value, account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="get_storage_lens_configuration",
        op_kwargs={"ConfigId": config_id, "AccountId": account_id},
    )


async def list_all(hub, ctx, account_id: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of Amazon S3 Storage Lens configurations. For more information about S3 Storage Lens, see Assessing your storage activity and usage with Amazon S3 Storage Lens  in the Amazon S3 User Guide.  To use this action, you must have permission to perform the s3:ListStorageLensConfigurations action. For more information, see Setting permissions to use Amazon S3 Storage Lens in the Amazon S3 User Guide.

    Args:
        account_id(str): The account ID of the requester.
        next_token(str, optional): A pagination token to request the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.storage_lens_configuration.init.list_all(
                ctx, account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.storage_lens_configuration.init.list_all account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="list_storage_lens_configurations",
        op_kwargs={"AccountId": account_id, "NextToken": next_token},
    )


async def put(
    hub,
    ctx,
    config_id: str,
    account_id: str,
    storage_lens_configuration: Dict,
    tags: List = None,
) -> None:
    r"""
    **Autogenerated function**

    Puts an Amazon S3 Storage Lens configuration. For more information about S3 Storage Lens, see Working with Amazon S3 Storage Lens in the Amazon S3 User Guide.  To use this action, you must have permission to perform the s3:PutStorageLensConfiguration action. For more information, see Setting permissions to use Amazon S3 Storage Lens in the Amazon S3 User Guide.

    Args:
        config_id(str): The ID of the S3 Storage Lens configuration.
        account_id(str): The account ID of the requester.
        storage_lens_configuration(Dict): The S3 Storage Lens configuration.
        tags(List, optional): The tag set of the S3 Storage Lens configuration.  You can set up to a maximum of 50 tags. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.storage_lens_configuration.init.put(
                ctx, config_id=value, account_id=value, storage_lens_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.storage_lens_configuration.init.put config_id=value, account_id=value, storage_lens_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="put_storage_lens_configuration",
        op_kwargs={
            "ConfigId": config_id,
            "AccountId": account_id,
            "StorageLensConfiguration": storage_lens_configuration,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    group_name: str,
    user_pool_id: str,
    description: str = None,
    role_arn: str = None,
    precedence: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new group in the specified user pool. Calling this action requires developer credentials.

    Args:
        group_name(str): The name of the group. Must be unique.
        user_pool_id(str): The user pool ID for the user pool.
        description(str, optional): A string containing the description of the group. Defaults to None.
        role_arn(str, optional): The role ARN for the group. Defaults to None.
        precedence(int, optional): A nonnegative integer value that specifies the precedence of this group relative to the other groups that a user can belong to in the user pool. Zero is the highest precedence value. Groups with lower Precedence values take precedence over groups with higher or null Precedence values. If a user belongs to two or more groups, it is the group with the lowest precedence value whose role ARN will be used in the cognito:roles and cognito:preferred_role claims in the user's tokens. Two groups can have the same Precedence value. If this happens, neither group takes precedence over the other. If two groups with the same Precedence have the same role ARN, that role is used in the cognito:preferred_role claim in tokens for users in each group. If the two groups have different role ARNs, the cognito:preferred_role claim is not set in users' tokens. The default Precedence value is null. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.group.create(
                ctx, group_name=value, user_pool_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.group.create group_name=value, user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="create_group",
        op_kwargs={
            "GroupName": group_name,
            "UserPoolId": user_pool_id,
            "Description": description,
            "RoleArn": role_arn,
            "Precedence": precedence,
        },
    )


async def delete(hub, ctx, group_name: str, user_pool_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a group. Calling this action requires developer credentials.

    Args:
        group_name(str): The name of the group.
        user_pool_id(str): The user pool ID for the user pool.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.group.delete(
                ctx, group_name=value, user_pool_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.group.delete group_name=value, user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="delete_group",
        op_kwargs={"GroupName": group_name, "UserPoolId": user_pool_id},
    )


async def get(hub, ctx, group_name: str, user_pool_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a group. Calling this action requires developer credentials.

    Args:
        group_name(str): The name of the group.
        user_pool_id(str): The user pool ID for the user pool.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.group.get(ctx, group_name=value, user_pool_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.group.get group_name=value, user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="get_group",
        op_kwargs={"GroupName": group_name, "UserPoolId": user_pool_id},
    )


async def list_all(
    hub, ctx, user_pool_id: str, limit: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the groups associated with a user pool. Calling this action requires developer credentials.

    Args:
        user_pool_id(str): The user pool ID for the user pool.
        limit(int, optional): The limit of the request to list groups. Defaults to None.
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.group.list_all(ctx, user_pool_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.group.list_all user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="list_groups",
        op_kwargs={"UserPoolId": user_pool_id, "Limit": limit, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    group_name: str,
    user_pool_id: str,
    description: str = None,
    role_arn: str = None,
    precedence: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified group with the specified attributes. Calling this action requires developer credentials.

    Args:
        group_name(str): The name of the group.
        user_pool_id(str): The user pool ID for the user pool.
        description(str, optional): A string containing the new description of the group. Defaults to None.
        role_arn(str, optional): The new role ARN for the group. This is used for setting the cognito:roles and cognito:preferred_role claims in the token. Defaults to None.
        precedence(int, optional): The new precedence value for the group. For more information about this parameter, see CreateGroup. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.group.update(
                ctx, group_name=value, user_pool_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.group.update group_name=value, user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="update_group",
        op_kwargs={
            "GroupName": group_name,
            "UserPoolId": user_pool_id,
            "Description": description,
            "RoleArn": role_arn,
            "Precedence": precedence,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    registry_name: str,
    limit: int = None,
    next_token: str = None,
    schema_name_prefix: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List the schemas.

    Args:
        limit(int, optional): . Defaults to None.
        next_token(str, optional): The token that specifies the next page of results to return. To request the first page, leave NextToken empty. The token will expire in 24 hours, and cannot be shared with other accounts. Defaults to None.
        registry_name(str): The name of the registry.
        schema_name_prefix(str, optional): Specifying this limits the results to only those schema names that start with the specified prefix. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.schemas.list(ctx, registry_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.schemas.list registry_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="list_schemas",
        op_kwargs={
            "Limit": limit,
            "NextToken": next_token,
            "RegistryName": registry_name,
            "SchemaNamePrefix": schema_name_prefix,
        },
    )


async def search(
    hub,
    ctx,
    keywords: str,
    registry_name: str,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Search the schemas

    Args:
        keywords(str): Specifying this limits the results to only schemas that include the provided keywords.
        limit(int, optional): . Defaults to None.
        next_token(str, optional): The token that specifies the next page of results to return. To request the first page, leave NextToken empty. The token will expire in 24 hours, and cannot be shared with other accounts. Defaults to None.
        registry_name(str): The name of the registry.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.schemas.search(ctx, keywords=value, registry_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.schemas.search keywords=value, registry_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="search_schemas",
        op_kwargs={
            "Keywords": keywords,
            "Limit": limit,
            "NextToken": next_token,
            "RegistryName": registry_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    sort_by: Dict = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of available bots.

    Args:
        sort_by(Dict, optional): Specifies sorting parameters for the list of bots. You can specify that the list be sorted by bot name in ascending or descending order. Defaults to None.
        filters(List, optional): Provides the specification of a filter used to limit the bots in the response to only those that match the filter specification. You can only specify one filter and one string to filter on. Defaults to None.
        max_results(int, optional): The maximum number of bots to return in each page of results. If there are fewer results than the maximum page size, only the actual number of results are returned. Defaults to None.
        next_token(str, optional): If the response from the ListBots operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bots.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bots.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="list_bots",
        op_kwargs={
            "sortBy": sort_by,
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    data_set_id: str = None,
    max_results: int = None,
    next_token: str = None,
    revision_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This operation lists your jobs sorted by CreatedAt in descending order.

    Args:
        data_set_id(str, optional): The unique identifier for a data set. Defaults to None.
        max_results(int, optional): The maximum number of results returned by a single call. Defaults to None.
        next_token(str, optional): The token value retrieved from a previous call to access the next page of results. Defaults to None.
        revision_id(str, optional): The unique identifier for a revision. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dataexchange.jobs.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dataexchange.jobs.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dataexchange",
        operation="list_jobs",
        op_kwargs={
            "DataSetId": data_set_id,
            "MaxResults": max_results,
            "NextToken": next_token,
            "RevisionId": revision_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, name: str, metric_name: str, change_token: str, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Creates a RuleGroup. A rule group is a collection of predefined rules that you add to a web ACL. You use UpdateRuleGroup to add rules to the rule group. Rule groups are subject to the following limits:   Three rule groups per account. You can request an increase to this limit by contacting customer support.   One rule group per web ACL.   Ten rules per rule group.   For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        name(str): A friendly name or description of the RuleGroup. You can't change Name after you create a RuleGroup.
        metric_name(str): A friendly name or description for the metrics for this RuleGroup. The name can contain only alphanumeric characters (A-Z, a-z, 0-9), with maximum length 128 and minimum length one. It can't contain whitespace or metric names reserved for AWS WAF, including "All" and "Default_Action." You can't change the name of the metric after you create the RuleGroup.
        change_token(str): The value returned by the most recent call to GetChangeToken.
        tags(List, optional): . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.rule.group.create(
                ctx, name=value, metric_name=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.rule.group.create name=value, metric_name=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="create_rule_group",
        op_kwargs={
            "Name": name,
            "MetricName": metric_name,
            "ChangeToken": change_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, rule_group_id: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Permanently deletes a RuleGroup. You can't delete a RuleGroup if it's still used in any WebACL objects or if it still includes any rules. If you just want to remove a RuleGroup from a WebACL, use UpdateWebACL. To permanently delete a RuleGroup from AWS WAF, perform the following steps:   Update the RuleGroup to remove rules, if any. For more information, see UpdateRuleGroup.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a DeleteRuleGroup request.   Submit a DeleteRuleGroup request.

    Args:
        rule_group_id(str): The RuleGroupId of the RuleGroup that you want to delete. RuleGroupId is returned by CreateRuleGroup and by ListRuleGroups.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.rule.group.delete(
                ctx, rule_group_id=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.rule.group.delete rule_group_id=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="delete_rule_group",
        op_kwargs={"RuleGroupId": rule_group_id, "ChangeToken": change_token},
    )


async def get(hub, ctx, rule_group_id: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns the RuleGroup that is specified by the RuleGroupId that you included in the GetRuleGroup request. To view the rules in a rule group, use ListActivatedRulesInRuleGroup.

    Args:
        rule_group_id(str): The RuleGroupId of the RuleGroup that you want to get. RuleGroupId is returned by CreateRuleGroup and by ListRuleGroups.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.rule.group.get(ctx, rule_group_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.rule.group.get rule_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="get_rule_group",
        op_kwargs={"RuleGroupId": rule_group_id},
    )


async def list_all(hub, ctx, next_marker: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns an array of RuleGroup objects.

    Args:
        next_marker(str, optional): If you specify a value for Limit and you have more RuleGroups than the value of Limit, AWS WAF returns a NextMarker value in the response that allows you to list another group of RuleGroups. For the second and subsequent ListRuleGroups requests, specify the value of NextMarker from the previous response to get information about another batch of RuleGroups. Defaults to None.
        limit(int, optional): Specifies the number of RuleGroups that you want AWS WAF to return for this request. If you have more RuleGroups than the number that you specify for Limit, the response includes a NextMarker value that you can use to get another batch of RuleGroups. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.rule.group.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.rule.group.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="list_rule_groups",
        op_kwargs={"NextMarker": next_marker, "Limit": limit},
    )


async def update(
    hub, ctx, rule_group_id: str, updates: List, change_token: str
) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Inserts or deletes ActivatedRule objects in a RuleGroup. You can only insert REGULAR rules into a rule group. You can have a maximum of ten rules per rule group. To create and configure a RuleGroup, perform the following steps:   Create and update the Rules that you want to include in the RuleGroup. See CreateRule.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateRuleGroup request.   Submit an UpdateRuleGroup request to add Rules to the RuleGroup.   Create and update a WebACL that contains the RuleGroup. See CreateWebACL.   If you want to replace one Rule with another, you delete the existing one and add the new one. For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        rule_group_id(str): The RuleGroupId of the RuleGroup that you want to update. RuleGroupId is returned by CreateRuleGroup and by ListRuleGroups.
        updates(List): An array of RuleGroupUpdate objects that you want to insert into or delete from a RuleGroup. You can only insert REGULAR rules into a rule group.  ActivatedRule|OverrideAction applies only when updating or adding a RuleGroup to a WebACL. In this case you do not use ActivatedRule|Action. For all other update requests, ActivatedRule|Action is used instead of ActivatedRule|OverrideAction.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.rule.group.update(
                ctx, rule_group_id=value, updates=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.rule.group.update rule_group_id=value, updates=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="update_rule_group",
        op_kwargs={
            "RuleGroupId": rule_group_id,
            "Updates": updates,
            "ChangeToken": change_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, human_loop_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified human loop for a flow definition. If the human loop was deleted, this operation will return a ResourceNotFoundException.

    Args:
        human_loop_name(str): The name of the human loop that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker_a2i_runtime_human_loop.delete(
                ctx, human_loop_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker_a2i_runtime_human_loop.delete human_loop_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker-a2i-runtime",
        operation="delete_human_loop",
        op_kwargs={"HumanLoopName": human_loop_name},
    )


async def describe(hub, ctx, human_loop_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the specified human loop. If the human loop was deleted, this operation will return a ResourceNotFoundException error.

    Args:
        human_loop_name(str): The name of the human loop that you want information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker_a2i_runtime_human_loop.describe(
                ctx, human_loop_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker_a2i_runtime_human_loop.describe human_loop_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker-a2i-runtime",
        operation="describe_human_loop",
        op_kwargs={"HumanLoopName": human_loop_name},
    )


async def list_all(
    hub,
    ctx,
    flow_definition_arn: str,
    creation_time_after: str = None,
    creation_time_before: str = None,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about human loops, given the specified parameters. If a human loop was deleted, it will not be included.

    Args:
        creation_time_after(str, optional): (Optional) The timestamp of the date when you want the human loops to begin in ISO 8601 format. For example, 2020-02-24. Defaults to None.
        creation_time_before(str, optional): (Optional) The timestamp of the date before which you want the human loops to begin in ISO 8601 format. For example, 2020-02-24. Defaults to None.
        flow_definition_arn(str): The Amazon Resource Name (ARN) of a flow definition.
        sort_order(str, optional): Optional. The order for displaying results. Valid values: Ascending and Descending. Defaults to None.
        next_token(str, optional): A token to display the next page of results. Defaults to None.
        max_results(int, optional): The total number of items to return. If the total number of available items is more than the value specified in MaxResults, then a NextToken is returned in the output. You can use this token to display the next page of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker_a2i_runtime_human_loop.list_all(
                ctx, flow_definition_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker_a2i_runtime_human_loop.list_all flow_definition_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker-a2i-runtime",
        operation="list_human_loops",
        op_kwargs={
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "FlowDefinitionArn": flow_definition_arn,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def start(
    hub,
    ctx,
    human_loop_name: str,
    flow_definition_arn: str,
    human_loop_input: Dict,
    data_attributes: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a human loop, provided that at least one activation condition is met.

    Args:
        human_loop_name(str): The name of the human loop.
        flow_definition_arn(str): The Amazon Resource Name (ARN) of the flow definition associated with this human loop.
        human_loop_input(Dict): An object that contains information about the human loop.
        data_attributes(Dict, optional): Attributes of the specified data. Use DataAttributes to specify if your data is free of personally identifiable information and/or free of adult content. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker_a2i_runtime_human_loop.start(
                ctx, human_loop_name=value, flow_definition_arn=value, human_loop_input=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker_a2i_runtime_human_loop.start human_loop_name=value, flow_definition_arn=value, human_loop_input=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker-a2i-runtime",
        operation="start_human_loop",
        op_kwargs={
            "HumanLoopName": human_loop_name,
            "FlowDefinitionArn": flow_definition_arn,
            "HumanLoopInput": human_loop_input,
            "DataAttributes": data_attributes,
        },
    )


async def stop(hub, ctx, human_loop_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops the specified human loop.

    Args:
        human_loop_name(str): The name of the human loop that you want to stop.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker_a2i_runtime_human_loop.stop(
                ctx, human_loop_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker_a2i_runtime_human_loop.stop human_loop_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker-a2i-runtime",
        operation="stop_human_loop",
        op_kwargs={"HumanLoopName": human_loop_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def set_(hub, ctx, rule_set_name: str, rule_name: str, after: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Sets the position of the specified receipt rule in the receipt rule set. For information about managing receipt rules, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        rule_set_name(str): The name of the receipt rule set that contains the receipt rule to reposition.
        rule_name(str): The name of the receipt rule to reposition.
        after(str, optional): The name of the receipt rule after which to place the specified receipt rule. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.receipt.rule.position.set(
                ctx, rule_set_name=value, rule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.receipt.rule.position.set rule_set_name=value, rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="set_receipt_rule_position",
        op_kwargs={"RuleSetName": rule_set_name, "RuleName": rule_name, "After": after},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def set_(
    hub,
    ctx,
    configuration: str,
    type_arn: str = None,
    configuration_alias: str = None,
    type_name: str = None,
    type_: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Specifies the configuration data for a registered CloudFormation extension, in the given account and region. To view the current configuration data for an extension, refer to the ConfigurationSchema element of DescribeType. For more information, see Configuring extensions at the account level in the CloudFormation User Guide.  It is strongly recommended that you use dynamic references to restrict sensitive configuration definitions, such as third-party credentials. For more details on dynamic references, see Using dynamic references to specify template values in the CloudFormation User Guide.

    Args:
        type_arn(str, optional): The Amazon Resource Name (ARN) for the extension, in this account and region. For public extensions, this will be the ARN assigned when you activate the type in this account and region. For private extensions, this will be the ARN assigned when you register the type in this account and region.  Do not include the extension versions suffix at the end of the ARN. You can set the configuration for an extension, but not for a specific extension version. Defaults to None.
        configuration(str): The configuration data for the extension, in this account and region.  The configuration data must be formatted as JSON, and validate against the schema returned in the ConfigurationSchema response element of API_DescribeType. For more information, see Defining account-level configuration data for an extension in the CloudFormation CLI User Guide.
        configuration_alias(str, optional): An alias by which to refer to this extension configuration data. Conditional: Specifying a configuration alias is required when setting a configuration for a resource type extension. Defaults to None.
        type_name(str, optional): The name of the extension. Conditional: You must specify ConfigurationArn, or Type and TypeName. Defaults to None.
        type_(str, optional): The type of extension. Conditional: You must specify ConfigurationArn, or Type and TypeName. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.type_.configuration.set(ctx, configuration=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.type_.configuration.set configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="set_type_configuration",
        op_kwargs={
            "TypeArn": type_arn,
            "Configuration": configuration,
            "ConfigurationAlias": configuration_alias,
            "TypeName": type_name,
            "Type": type_,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, pipeline: Dict, tags: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a pipeline.  In the pipeline structure, you must include either artifactStore or artifactStores in your pipeline, but you cannot use both. If you create a cross-region action in your pipeline, you must use artifactStores.

    Args:
        pipeline(Dict): Represents the structure of actions and stages to be performed in the pipeline. .
        tags(List, optional): The tags for the pipeline. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.pipeline.init.create(ctx, pipeline=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.pipeline.init.create pipeline=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="create_pipeline",
        op_kwargs={"pipeline": pipeline, "tags": tags},
    )


async def delete(hub, ctx, name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified pipeline.

    Args:
        name(str): The name of the pipeline to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.pipeline.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.pipeline.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="delete_pipeline",
        op_kwargs={"name": name},
    )


async def get(hub, ctx, name: str, version: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the metadata, structure, stages, and actions of a pipeline. Can be used to return the entire structure of a pipeline in JSON format, which can then be modified and used to update the pipeline structure with UpdatePipeline.

    Args:
        name(str): The name of the pipeline for which you want to get information. Pipeline names must be unique under an AWS user account.
        version(int, optional): The version number of the pipeline. If you do not specify a version, defaults to the current version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.pipeline.init.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.pipeline.init.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="get_pipeline",
        op_kwargs={"name": name, "version": version},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets a summary of all of the pipelines associated with your account.

    Args:
        next_token(str, optional): An identifier that was returned from the previous list pipelines call. It can be used to return the next set of pipelines in the list. Defaults to None.
        max_results(int, optional): The maximum number of pipelines to return in a single call. To retrieve the remaining pipelines, make another call with the returned nextToken value. The minimum value you can specify is 1. The maximum accepted value is 1000. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.pipeline.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.pipeline.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="list_pipelines",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(hub, ctx, pipeline: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Updates a specified pipeline with edits or changes to its structure. Use a JSON file with the pipeline structure and UpdatePipeline to provide the full structure of the pipeline. Updating the pipeline increases the version number of the pipeline by 1.

    Args:
        pipeline(Dict): The name of the pipeline to be updated.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.pipeline.init.update(ctx, pipeline=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.pipeline.init.update pipeline=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="update_pipeline",
        op_kwargs={"pipeline": pipeline},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, cluster_arn: str, control_panel_name: str, client_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new control panel. A control panel represents a group of routing controls that can be changed together in a single transaction. You can use a control panel to centrally view the operational status of applications across your organization, and trigger multi-app failovers in a single transaction, for example, to fail over an Availability Zone or AWS Region.

    Args:
        client_token(str, optional): Unique client idempotency token. Defaults to None.
        cluster_arn(str): The Amazon Resource Name (ARN) of the cluster for the control panel.
        control_panel_name(str): The name of the control panel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.control_panel.create(
                ctx, cluster_arn=value, control_panel_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.control_panel.create cluster_arn=value, control_panel_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="create_control_panel",
        op_kwargs={
            "ClientToken": client_token,
            "ClusterArn": cluster_arn,
            "ControlPanelName": control_panel_name,
        },
    )


async def delete(hub, ctx, control_panel_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a control panel.

    Args:
        control_panel_arn(str): The Amazon Resource Name (ARN) of the control panel that you're deleting.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.control_panel.delete(
                ctx, control_panel_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.control_panel.delete control_panel_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="delete_control_panel",
        op_kwargs={"ControlPanelArn": control_panel_arn},
    )


async def describe(hub, ctx, control_panel_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Displays details about a control panel.

    Args:
        control_panel_arn(str): The Amazon Resource Name (ARN) of the control panel that you're getting details for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.control_panel.describe(
                ctx, control_panel_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.control_panel.describe control_panel_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="describe_control_panel",
        op_kwargs={"ControlPanelArn": control_panel_arn},
    )


async def list_all(
    hub, ctx, cluster_arn: str = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of control panels for a cluster.

    Args:
        cluster_arn(str, optional): The Amazon Resource Name (ARN) of a cluster. Defaults to None.
        max_results(int, optional): The number of objects that you want to return with this call. Defaults to None.
        next_token(str, optional): The token that identifies which batch of results you want to see. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.control_panel.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.control_panel.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="list_control_panels",
        op_kwargs={
            "ClusterArn": cluster_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(hub, ctx, control_panel_arn: str, control_panel_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates a control panel. The only update you can make to a control panel is to change the name of the control panel.

    Args:
        control_panel_arn(str): The Amazon Resource Name (ARN) of the control panel.
        control_panel_name(str): The name of the control panel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.control_panel.update(
                ctx, control_panel_arn=value, control_panel_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.control_panel.update control_panel_arn=value, control_panel_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="update_control_panel",
        op_kwargs={
            "ControlPanelArn": control_panel_arn,
            "ControlPanelName": control_panel_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def delete_multiple(
    hub, ctx, api_id: str, route_key: str, stage_name: str
) -> None:
    r"""
    **Autogenerated function**

    Deletes the RouteSettings for a stage.

    Args:
        api_id(str): The API identifier.
        route_key(str): The route key.
        stage_name(str): The stage name. Stage names can only contain alphanumeric characters, hyphens, and underscores. Maximum length is 128 characters.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.route.setting.delete_multiple(
                ctx, api_id=value, route_key=value, stage_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.route.setting.delete_multiple api_id=value, route_key=value, stage_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="delete_route_settings",
        op_kwargs={"ApiId": api_id, "RouteKey": route_key, "StageName": stage_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    project_arn: str,
    version_name: str,
    output_config: Dict,
    training_data: Dict,
    testing_data: Dict,
    tags: Dict = None,
    kms_key_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new version of a model and begins training. Models are managed as part of an Amazon Rekognition Custom Labels project. You can specify one training dataset and one testing dataset. The response from CreateProjectVersion is an Amazon Resource Name (ARN) for the version of the model.  Training takes a while to complete. You can get the current status by calling DescribeProjectVersions. Once training has successfully completed, call DescribeProjectVersions to get the training results and evaluate the model.  After evaluating the model, you start the model by calling StartProjectVersion. This operation requires permissions to perform the rekognition:CreateProjectVersion action.

    Args:
        project_arn(str): The ARN of the Amazon Rekognition Custom Labels project that manages the model that you want to train.
        version_name(str): A name for the version of the model. This value must be unique.
        output_config(Dict): The Amazon S3 location to store the results of training.
        training_data(Dict): The dataset to use for training. .
        testing_data(Dict): The dataset to use for testing.
        tags(Dict, optional):  A set of tags (key-value pairs) that you want to attach to the model. . Defaults to None.
        kms_key_id(str, optional): The identifier for your AWS Key Management Service (AWS KMS) customer master key (CMK). You can supply the Amazon Resource Name (ARN) of your CMK, the ID of your CMK, or an alias for your CMK. The key is used to encrypt training and test images copied into the service for model training. Your source images are unaffected. The key is also used to encrypt training results and manifest files written to the output Amazon S3 bucket (OutputConfig). If you don't specify a value for KmsKeyId, images copied into the service are encrypted using a key that AWS owns and manages. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.project.version.create(
                ctx,
                project_arn=value,
                version_name=value,
                output_config=value,
                training_data=value,
                testing_data=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.project.version.create project_arn=value, version_name=value, output_config=value, training_data=value, testing_data=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="create_project_version",
        op_kwargs={
            "ProjectArn": project_arn,
            "VersionName": version_name,
            "OutputConfig": output_config,
            "TrainingData": training_data,
            "TestingData": testing_data,
            "Tags": tags,
            "KmsKeyId": kms_key_id,
        },
    )


async def delete(hub, ctx, project_version_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an Amazon Rekognition Custom Labels model.  You can't delete a model if it is running or if it is training. To check the status of a model, use the Status field returned from DescribeProjectVersions. To stop a running model call StopProjectVersion. If the model is training, wait until it finishes. This operation requires permissions to perform the rekognition:DeleteProjectVersion action.

    Args:
        project_version_arn(str): The Amazon Resource Name (ARN) of the model version that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.project.version.delete(
                ctx, project_version_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.project.version.delete project_version_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="delete_project_version",
        op_kwargs={"ProjectVersionArn": project_version_arn},
    )


async def describe_all(
    hub,
    ctx,
    project_arn: str,
    version_names: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists and describes the models in an Amazon Rekognition Custom Labels project. You can specify up to 10 model versions in ProjectVersionArns. If you don't specify a value, descriptions for all models are returned. This operation requires permissions to perform the rekognition:DescribeProjectVersions action.

    Args:
        project_arn(str): The Amazon Resource Name (ARN) of the project that contains the models you want to describe.
        version_names(List, optional): A list of model version names that you want to describe. You can add up to 10 model version names to the list. If you don't specify a value, all model descriptions are returned. A version name is part of a model (ProjectVersion) ARN. For example, my-model.2020-01-21T09.10.15 is the version name in the following ARN. arn:aws:rekognition:us-east-1:123456789012:project/getting-started/version/my-model.2020-01-21T09.10.15/1234567890123. Defaults to None.
        next_token(str, optional): If the previous response was incomplete (because there is more results to retrieve), Amazon Rekognition Custom Labels returns a pagination token in the response. You can use this pagination token to retrieve the next set of results. . Defaults to None.
        max_results(int, optional): The maximum number of results to return per paginated call. The largest value you can specify is 100. If you specify a value greater than 100, a ValidationException error occurs. The default value is 100. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.project.version.describe_all(ctx, project_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.project.version.describe_all project_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="describe_project_versions",
        op_kwargs={
            "ProjectArn": project_arn,
            "VersionNames": version_names,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def start(hub, ctx, project_version_arn: str, min_inference_units: int) -> Dict:
    r"""
    **Autogenerated function**

    Starts the running of the version of a model. Starting a model takes a while to complete. To check the current state of the model, use DescribeProjectVersions. Once the model is running, you can detect custom labels in new images by calling DetectCustomLabels.  You are charged for the amount of time that the model is running. To stop a running model, call StopProjectVersion.  This operation requires permissions to perform the rekognition:StartProjectVersion action.

    Args:
        project_version_arn(str): The Amazon Resource Name(ARN) of the model version that you want to start.
        min_inference_units(int): The minimum number of inference units to use. A single inference unit represents 1 hour of processing and can support up to 5 Transaction Pers Second (TPS). Use a higher number to increase the TPS throughput of your model. You are charged for the number of inference units that you use. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.project.version.start(
                ctx, project_version_arn=value, min_inference_units=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.project.version.start project_version_arn=value, min_inference_units=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="start_project_version",
        op_kwargs={
            "ProjectVersionArn": project_version_arn,
            "MinInferenceUnits": min_inference_units,
        },
    )


async def stop(hub, ctx, project_version_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops a running model. The operation might take a while to complete. To check the current status, call DescribeProjectVersions.

    Args:
        project_version_arn(str): The Amazon Resource Name (ARN) of the model version that you want to delete. This operation requires permissions to perform the rekognition:StopProjectVersion action.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.project.version.stop(ctx, project_version_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.project.version.stop project_version_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="stop_project_version",
        op_kwargs={"ProjectVersionArn": project_version_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a job document.

    Args:
        job_id(str): The unique identifier you assigned to this job when it was created.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.job.document.get(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.job.document.get job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="get_job_document",
        op_kwargs={"jobId": job_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    content: str,
    name: str,
    requires: List = None,
    attachments: List = None,
    display_name: str = None,
    version_name: str = None,
    document_type: str = None,
    document_format: str = None,
    target_type: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Amazon Web Services Systems Manager (SSM document). An SSM document defines the actions that Systems Manager performs on your managed instances. For more information about SSM documents, including information about supported schemas, features, and syntax, see Amazon Web Services Systems Manager Documents in the Amazon Web Services Systems Manager User Guide.

    Args:
        content(str): The content for the new SSM document in JSON or YAML format. We recommend storing the contents for your new document in an external JSON or YAML file and referencing the file in a command. For examples, see the following topics in the Amazon Web Services Systems Manager User Guide.    Create an SSM document (Amazon Web Services API)     Create an SSM document (Amazon Web Services CLI)     Create an SSM document (API)   .
        requires(List, optional): A list of SSM documents required by a document. This parameter is used exclusively by AppConfig. When a user creates an AppConfig configuration in an SSM document, the user must also specify a required document for validation purposes. In this case, an ApplicationConfiguration document requires an ApplicationConfigurationSchema document for validation purposes. For more information, see What is AppConfig? in the AppConfig User Guide. Defaults to None.
        attachments(List, optional): A list of key-value pairs that describe attachments to a version of a document. Defaults to None.
        name(str): A name for the SSM document.  You can't use the following strings as document name prefixes. These are reserved by Amazon Web Services for use as document name prefixes:    aws-     amazon     amzn    .
        display_name(str, optional): An optional field where you can specify a friendly name for the SSM document. This value can differ for each version of the document. You can update this value at a later time using the UpdateDocument operation. Defaults to None.
        version_name(str, optional): An optional field specifying the version of the artifact you are creating with the document. For example, "Release 12, Update 6". This value is unique across all versions of a document, and can't be changed. Defaults to None.
        document_type(str, optional): The type of document to create. Defaults to None.
        document_format(str, optional): Specify the document format for the request. The document format can be JSON, YAML, or TEXT. JSON is the default format. Defaults to None.
        target_type(str, optional): Specify a target type to define the kinds of resources the document can run on. For example, to run a document on EC2 instances, specify the following value: /AWS::EC2::Instance. If you specify a value of '/' the document can run on all types of resources. If you don't specify a value, the document can't run on any resources. For a list of valid resource types, see Amazon Web Services resource and property types reference in the CloudFormation User Guide. . Defaults to None.
        tags(List, optional): Optional metadata that you assign to a resource. Tags enable you to categorize a resource in different ways, such as by purpose, owner, or environment. For example, you might want to tag an SSM document to identify the types of targets or the environment where it will run. In this case, you could specify the following key-value pairs:    Key=OS,Value=Windows     Key=Environment,Value=Production     To add tags to an existing SSM document, use the AddTagsToResource operation. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.document.init.create(ctx, content=value, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.document.init.create content=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="create_document",
        op_kwargs={
            "Content": content,
            "Requires": requires,
            "Attachments": attachments,
            "Name": name,
            "DisplayName": display_name,
            "VersionName": version_name,
            "DocumentType": document_type,
            "DocumentFormat": document_format,
            "TargetType": target_type,
            "Tags": tags,
        },
    )


async def delete(
    hub,
    ctx,
    name: str,
    document_version: str = None,
    version_name: str = None,
    force: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the Amazon Web Services Systems Manager document (SSM document) and all instance associations to the document. Before you delete the document, we recommend that you use DeleteAssociation to disassociate all instances that are associated with the document.

    Args:
        name(str): The name of the document.
        document_version(str, optional): The version of the document that you want to delete. If not provided, all versions of the document are deleted. Defaults to None.
        version_name(str, optional): The version name of the document that you want to delete. If not provided, all versions of the document are deleted. Defaults to None.
        force(bool, optional): Some SSM document types require that you specify a Force flag before you can delete the document. For example, you must specify a Force flag to delete a document of type ApplicationConfigurationSchema. You can restrict access to the Force flag in an Identity and Access Management (IAM) policy. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.document.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.document.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="delete_document",
        op_kwargs={
            "Name": name,
            "DocumentVersion": document_version,
            "VersionName": version_name,
            "Force": force,
        },
    )


async def describe(
    hub, ctx, name: str, document_version: str = None, version_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified Amazon Web Services Systems Manager document (SSM document).

    Args:
        name(str): The name of the SSM document.
        document_version(str, optional): The document version for which you want information. Can be a specific version or the default version. Defaults to None.
        version_name(str, optional): An optional field specifying the version of the artifact associated with the document. For example, "Release 12, Update 6". This value is unique across all versions of a document, and can't be changed. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.document.init.describe(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.document.init.describe name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_document",
        op_kwargs={
            "Name": name,
            "DocumentVersion": document_version,
            "VersionName": version_name,
        },
    )


async def get(
    hub,
    ctx,
    name: str,
    version_name: str = None,
    document_version: str = None,
    document_format: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the contents of the specified Amazon Web Services Systems Manager document (SSM document).

    Args:
        name(str): The name of the SSM document.
        version_name(str, optional): An optional field specifying the version of the artifact associated with the document. For example, "Release 12, Update 6". This value is unique across all versions of a document and can't be changed. Defaults to None.
        document_version(str, optional): The document version for which you want information. Defaults to None.
        document_format(str, optional): Returns the document in the specified format. The document format can be either JSON or YAML. JSON is the default format. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.document.init.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.document.init.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_document",
        op_kwargs={
            "Name": name,
            "VersionName": version_name,
            "DocumentVersion": document_version,
            "DocumentFormat": document_format,
        },
    )


async def list_all(
    hub,
    ctx,
    document_filter_list: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns all Systems Manager (SSM) documents in the current account and Region. You can limit the results of this request by using a filter.

    Args:
        document_filter_list(List, optional): This data type is deprecated. Instead, use Filters. Defaults to None.
        filters(List, optional): One or more DocumentKeyValuesFilter objects. Use a filter to return a more specific list of results. For keys, you can specify one or more key-value pair tags that have been applied to a document. Other valid keys include Owner, Name, PlatformTypes, DocumentType, and TargetType. For example, to return documents you own use Key=Owner,Values=Self. To specify a custom key-value pair, use the format Key=tag:tagName,Values=valueName.  This API operation only supports filtering documents by using a single tag key and one or more tag values. For example: Key=tag:tagName,Values=valueName1,valueName2  . Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.document.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.document.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="list_documents",
        op_kwargs={
            "DocumentFilterList": document_filter_list,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    content: str,
    name: str,
    attachments: List = None,
    display_name: str = None,
    version_name: str = None,
    document_version: str = None,
    document_format: str = None,
    target_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates one or more values for an SSM document.

    Args:
        content(str): A valid JSON or YAML string.
        attachments(List, optional): A list of key-value pairs that describe attachments to a version of a document. Defaults to None.
        name(str): The name of the SSM document that you want to update.
        display_name(str, optional): The friendly name of the SSM document that you want to update. This value can differ for each version of the document. If you don't specify a value for this parameter in your request, the existing value is applied to the new document version. Defaults to None.
        version_name(str, optional): An optional field specifying the version of the artifact you are updating with the document. For example, "Release 12, Update 6". This value is unique across all versions of a document, and can't be changed. Defaults to None.
        document_version(str, optional): The version of the document that you want to update. Currently, Systems Manager supports updating only the latest version of the document. You can specify the version number of the latest version or use the $LATEST variable. Defaults to None.
        document_format(str, optional): Specify the document format for the new document version. Systems Manager supports JSON and YAML documents. JSON is the default format. Defaults to None.
        target_type(str, optional): Specify a new target type for the document. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.document.init.update(ctx, content=value, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.document.init.update content=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="update_document",
        op_kwargs={
            "Content": content,
            "Attachments": attachments,
            "Name": name,
            "DisplayName": display_name,
            "VersionName": version_name,
            "DocumentVersion": document_version,
            "DocumentFormat": document_format,
            "TargetType": target_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, location_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the configuration of a location used by AWS DataSync.

    Args:
        location_arn(str): The Amazon Resource Name (ARN) of the location to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.location.init.delete(ctx, location_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.location.init.delete location_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="delete_location",
        op_kwargs={"LocationArn": location_arn},
    )


async def list_all(
    hub, ctx, max_results: int = None, next_token: str = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of source and destination locations. If you have more locations than are returned in a response (that is, the response returns only a truncated list of your agents), the response contains a token that you can specify in your next request to fetch the next page of locations.

    Args:
        max_results(int, optional): The maximum number of locations to return. Defaults to None.
        next_token(str, optional): An opaque string that indicates the position at which to begin the next list of locations. Defaults to None.
        filters(List, optional): You can use API filters to narrow down the list of resources returned by ListLocations. For example, to retrieve all tasks on a specific source location, you can use ListLocations with filter name LocationType S3 and Operator Equals. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.location.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.location.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="list_locations",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "Filters": filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def accept(hub, ctx, grant_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Accepts the specified grant.

    Args:
        grant_arn(str): Amazon Resource Name (ARN) of the grant.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.grant.init.accept(ctx, grant_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.grant.init.accept grant_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="accept_grant",
        op_kwargs={"GrantArn": grant_arn},
    )


async def create(
    hub,
    ctx,
    client_token: str,
    grant_name: str,
    license_arn: str,
    principals: List,
    home_region: str,
    allowed_operations: List,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a grant for the specified license. A grant shares the use of license entitlements with specific AWS accounts.

    Args:
        client_token(str): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
        grant_name(str): Grant name.
        license_arn(str): Amazon Resource Name (ARN) of the license.
        principals(List): The grant principals.
        home_region(str): Home Region of the grant.
        allowed_operations(List): Allowed operations for the grant.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.grant.init.create(
                ctx,
                client_token=value,
                grant_name=value,
                license_arn=value,
                principals=value,
                home_region=value,
                allowed_operations=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.grant.init.create client_token=value, grant_name=value, license_arn=value, principals=value, home_region=value, allowed_operations=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="create_grant",
        op_kwargs={
            "ClientToken": client_token,
            "GrantName": grant_name,
            "LicenseArn": license_arn,
            "Principals": principals,
            "HomeRegion": home_region,
            "AllowedOperations": allowed_operations,
        },
    )


async def delete(
    hub, ctx, grant_arn: str, version: str, status_reason: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified grant.

    Args:
        grant_arn(str): Amazon Resource Name (ARN) of the grant.
        status_reason(str, optional): . Defaults to None.
        version(str): Current version of the grant.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.grant.init.delete(
                ctx, grant_arn=value, version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.grant.init.delete grant_arn=value, version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="delete_grant",
        op_kwargs={
            "GrantArn": grant_arn,
            "StatusReason": status_reason,
            "Version": version,
        },
    )


async def get(hub, ctx, grant_arn: str, version: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets detailed information about the specified grant.

    Args:
        grant_arn(str): Amazon Resource Name (ARN) of the grant.
        version(str, optional): Grant version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.grant.init.get(ctx, grant_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.grant.init.get grant_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="get_grant",
        op_kwargs={"GrantArn": grant_arn, "Version": version},
    )


async def reject(hub, ctx, grant_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Rejects the specified grant.

    Args:
        grant_arn(str): Amazon Resource Name (ARN) of the grant.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.grant.init.reject(ctx, grant_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.grant.init.reject grant_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="reject_grant",
        op_kwargs={"GrantArn": grant_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, exclusion_arns: List, locale: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes the exclusions that are specified by the exclusions' ARNs.

    Args:
        exclusion_arns(List): The list of ARNs that specify the exclusions that you want to describe.
        locale(str, optional): The locale into which you want to translate the exclusion's title, description, and recommendation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.exclusion.init.describe_all(ctx, exclusion_arns=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.exclusion.init.describe_all exclusion_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="describe_exclusions",
        op_kwargs={"exclusionArns": exclusion_arns, "locale": locale},
    )


async def list_all(
    hub, ctx, assessment_run_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    List exclusions that are generated by the assessment run.

    Args:
        assessment_run_arn(str): The ARN of the assessment run that generated the exclusions that you want to list.
        next_token(str, optional): You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListExclusionsRequest action. Subsequent calls to the action fill nextToken in the request with the value of nextToken from the previous response to continue listing data. Defaults to None.
        max_results(int, optional): You can use this parameter to indicate the maximum number of items you want in the response. The default value is 100. The maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.exclusion.init.list_all(ctx, assessment_run_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.exclusion.init.list_all assessment_run_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="list_exclusions",
        op_kwargs={
            "assessmentRunArn": assessment_run_arn,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str,
    definition_type: str,
    definition: Dict,
    idempotency_token: str,
    description: str = None,
    accept_language: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a self-service action.

    Args:
        name(str): The self-service action name.
        definition_type(str): The service action definition type. For example, SSM_AUTOMATION.
        definition(Dict): The self-service action definition. Can be one of the following:  Name  The name of the AWS Systems Manager document (SSM document). For example, AWS-RestartEC2Instance. If you are using a shared SSM document, you must provide the ARN instead of the name.  Version  The AWS Systems Manager automation document version. For example, "Version": "1"   AssumeRole  The Amazon Resource Name (ARN) of the role that performs the self-service actions on your behalf. For example, "AssumeRole": "arn:aws:iam::12345678910:role/ActionRole". To reuse the provisioned product launch role, set to "AssumeRole": "LAUNCH_ROLE".  Parameters  The list of parameters in JSON format. For example: [{\"Name\":\"InstanceId\",\"Type\":\"TARGET\"}] or [{\"Name\":\"InstanceId\",\"Type\":\"TEXT_VALUE\"}].  .
        description(str, optional): The self-service action description. Defaults to None.
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        idempotency_token(str): A unique identifier that you provide to ensure idempotency. If multiple requests differ only by the idempotency token, the same response is returned for each repeated request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.service_action.init.create(
                ctx, name=value, definition_type=value, definition=value, idempotency_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.service_action.init.create name=value, definition_type=value, definition=value, idempotency_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="create_service_action",
        op_kwargs={
            "Name": name,
            "DefinitionType": definition_type,
            "Definition": definition,
            "Description": description,
            "AcceptLanguage": accept_language,
            "IdempotencyToken": idempotency_token,
        },
    )


async def delete(hub, ctx, id_: str, accept_language: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a self-service action.

    Args:
        id_(str): The self-service action identifier. For example, act-fs7abcd89wxyz.
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.service_action.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.service_action.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="delete_service_action",
        op_kwargs={"Id": id_, "AcceptLanguage": accept_language},
    )


async def describe(hub, ctx, id_: str, accept_language: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes a self-service action.

    Args:
        id_(str): The self-service action identifier.
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.service_action.init.describe(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.service_action.init.describe id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="describe_service_action",
        op_kwargs={"Id": id_, "AcceptLanguage": accept_language},
    )


async def list_all(
    hub, ctx, accept_language: str = None, page_size: int = None, page_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all self-service actions.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        page_size(int, optional): The maximum number of items to return with this call. Defaults to None.
        page_token(str, optional): The page token for the next set of results. To retrieve the first set of results, use null. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.service_action.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.service_action.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="list_service_actions",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "PageSize": page_size,
            "PageToken": page_token,
        },
    )


async def update(
    hub,
    ctx,
    id_: str,
    name: str = None,
    definition: Dict = None,
    description: str = None,
    accept_language: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a self-service action.

    Args:
        id_(str): The self-service action identifier.
        name(str, optional): The self-service action name. Defaults to None.
        definition(Dict, optional): A map that defines the self-service action. Defaults to None.
        description(str, optional): The self-service action description. Defaults to None.
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.service_action.init.update(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.service_action.init.update id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="update_service_action",
        op_kwargs={
            "Id": id_,
            "Name": name,
            "Definition": definition,
            "Description": description,
            "AcceptLanguage": accept_language,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    job_id: str,
    max_results: int = None,
    next_token: str = None,
    sort_by: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the face search results for Amazon Rekognition Video face search started by StartFaceSearch. The search returns faces in a collection that match the faces of persons detected in a video. It also includes the time(s) that faces are matched in the video. Face search in a video is an asynchronous operation. You start face search by calling to StartFaceSearch which returns a job identifier (JobId). When the search operation finishes, Amazon Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic registered in the initial call to StartFaceSearch. To get the search results, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetFaceSearch and pass the job identifier (JobId) from the initial call to StartFaceSearch. For more information, see Searching Faces in a Collection in the Amazon Rekognition Developer Guide. The search results are retured in an array, Persons, of PersonMatch objects. EachPersonMatch element contains details about the matching faces in the input collection, person information (facial attributes, bounding boxes, and person identifer) for the matched person, and the time the person was matched in the video.   GetFaceSearch only returns the default facial attributes (BoundingBox, Confidence, Landmarks, Pose, and Quality). The other facial attributes listed in the Face object of the following response syntax are not returned. For more information, see FaceDetail in the Amazon Rekognition Developer Guide.   By default, the Persons array is sorted by the time, in milliseconds from the start of the video, persons are matched. You can also sort by persons by specifying INDEX for the SORTBY input parameter.

    Args:
        job_id(str): The job identifer for the search request. You get the job identifier from an initial call to StartFaceSearch.
        max_results(int, optional): Maximum number of results to return per paginated call. The largest value you can specify is 1000. If you specify a value greater than 1000, a maximum of 1000 results is returned. The default value is 1000. Defaults to None.
        next_token(str, optional): If the previous response was incomplete (because there is more search results to retrieve), Amazon Rekognition Video returns a pagination token in the response. You can use this pagination token to retrieve the next set of search results. . Defaults to None.
        sort_by(str, optional): Sort to use for grouping faces in the response. Use TIMESTAMP to group faces by the time that they are recognized. Use INDEX to sort by recognized faces. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.face.search.get(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.face.search.get job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="get_face_search",
        op_kwargs={
            "JobId": job_id,
            "MaxResults": max_results,
            "NextToken": next_token,
            "SortBy": sort_by,
        },
    )


async def start(
    hub,
    ctx,
    video: Dict,
    collection_id: str,
    client_request_token: str = None,
    face_match_threshold: float = None,
    notification_channel: Dict = None,
    job_tag: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts the asynchronous search for faces in a collection that match the faces of persons detected in a stored video. The video must be stored in an Amazon S3 bucket. Use Video to specify the bucket name and the filename of the video. StartFaceSearch returns a job identifier (JobId) which you use to get the search results once the search has completed. When searching is finished, Amazon Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic that you specify in NotificationChannel. To get the search results, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetFaceSearch and pass the job identifier (JobId) from the initial call to StartFaceSearch. For more information, see procedure-person-search-videos.

    Args:
        video(Dict): The video you want to search. The video must be stored in an Amazon S3 bucket. .
        client_request_token(str, optional): Idempotent token used to identify the start request. If you use the same token with multiple StartFaceSearch requests, the same JobId is returned. Use ClientRequestToken to prevent the same job from being accidently started more than once. . Defaults to None.
        face_match_threshold(float, optional): The minimum confidence in the person match to return. For example, don't return any matches where confidence in matches is less than 70%. The default value is 80%. Defaults to None.
        collection_id(str): ID of the collection that contains the faces you want to search for.
        notification_channel(Dict, optional): The ARN of the Amazon SNS topic to which you want Amazon Rekognition Video to publish the completion status of the search. . Defaults to None.
        job_tag(str, optional): An identifier you specify that's returned in the completion notification that's published to your Amazon Simple Notification Service topic. For example, you can use JobTag to group related jobs and identify them in the completion notification. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.face.search.start(
                ctx, video=value, collection_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.face.search.start video=value, collection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="start_face_search",
        op_kwargs={
            "Video": video,
            "ClientRequestToken": client_request_token,
            "FaceMatchThreshold": face_match_threshold,
            "CollectionId": collection_id,
            "NotificationChannel": notification_channel,
            "JobTag": job_tag,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, secret_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the resource-based permission policy attached to the secret.  Minimum permissions  To run this command, you must have the following permissions:   secretsmanager:DeleteResourcePolicy    Related operations    To attach a resource policy to a secret, use PutResourcePolicy.   To retrieve the current resource-based policy attached to a secret, use GetResourcePolicy.   To list all of the currently available secrets, use ListSecrets.

    Args:
        secret_id(str): Specifies the secret that you want to delete the attached resource-based policy for. You can specify either the Amazon Resource Name (ARN) or the friendly name of the secret.  If you specify an ARN, we generally recommend that you specify a complete ARN. You can specify a partial ARN too—for example, if you don’t include the final hyphen and six random characters that Secrets Manager adds at the end of the ARN when you created the secret. A partial ARN match can work as long as it uniquely matches only one secret. However, if your secret has a name that ends in a hyphen followed by six characters (before Secrets Manager adds the hyphen and six characters to the ARN) and you try to use that as a partial ARN, then those characters cause Secrets Manager to assume that you’re specifying a complete ARN. This confusion can cause unexpected results. To avoid this situation, we recommend that you don’t create secret names ending with a hyphen followed by six characters. If you specify an incomplete ARN without the random suffix, and instead provide the 'friendly name', you must not include the random suffix. If you do include the random suffix added by Secrets Manager, you receive either a ResourceNotFoundException or an AccessDeniedException error, depending on your permissions. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.secretsmanager.resource.policy.delete(ctx, secret_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.secretsmanager.resource.policy.delete secret_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="secretsmanager",
        operation="delete_resource_policy",
        op_kwargs={"SecretId": secret_id},
    )


async def get(hub, ctx, secret_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the JSON text of the resource-based policy document attached to the specified secret. The JSON request string input and response output displays formatted code with white space and line breaks for better readability. Submit your input as a single line JSON string.  Minimum permissions  To run this command, you must have the following permissions:   secretsmanager:GetResourcePolicy    Related operations    To attach a resource policy to a secret, use PutResourcePolicy.   To delete the resource-based policy attached to a secret, use DeleteResourcePolicy.   To list all of the currently available secrets, use ListSecrets.

    Args:
        secret_id(str): Specifies the secret that you want to retrieve the attached resource-based policy for. You can specify either the Amazon Resource Name (ARN) or the friendly name of the secret.  If you specify an ARN, we generally recommend that you specify a complete ARN. You can specify a partial ARN too—for example, if you don’t include the final hyphen and six random characters that Secrets Manager adds at the end of the ARN when you created the secret. A partial ARN match can work as long as it uniquely matches only one secret. However, if your secret has a name that ends in a hyphen followed by six characters (before Secrets Manager adds the hyphen and six characters to the ARN) and you try to use that as a partial ARN, then those characters cause Secrets Manager to assume that you’re specifying a complete ARN. This confusion can cause unexpected results. To avoid this situation, we recommend that you don’t create secret names ending with a hyphen followed by six characters. If you specify an incomplete ARN without the random suffix, and instead provide the 'friendly name', you must not include the random suffix. If you do include the random suffix added by Secrets Manager, you receive either a ResourceNotFoundException or an AccessDeniedException error, depending on your permissions. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.secretsmanager.resource.policy.get(ctx, secret_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.secretsmanager.resource.policy.get secret_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="secretsmanager",
        operation="get_resource_policy",
        op_kwargs={"SecretId": secret_id},
    )


async def put(
    hub, ctx, secret_id: str, resource_policy: str, block_public_policy: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Attaches the contents of the specified resource-based permission policy to a secret. A resource-based policy is optional. Alternatively, you can use IAM identity-based policies that specify the secret's Amazon Resource Name (ARN) in the policy statement's Resources element. You can also use a combination of both identity-based and resource-based policies. The affected users and roles receive the permissions that are permitted by all of the relevant policies. For more information, see Using Resource-Based Policies for Amazon Web Services Secrets Manager. For the complete description of the Amazon Web Services policy syntax and grammar, see IAM JSON Policy Reference in the IAM User Guide.  Minimum permissions  To run this command, you must have the following permissions:   secretsmanager:PutResourcePolicy    Related operations    To retrieve the resource policy attached to a secret, use GetResourcePolicy.   To delete the resource-based policy attached to a secret, use DeleteResourcePolicy.   To list all of the currently available secrets, use ListSecrets.

    Args:
        secret_id(str): Specifies the secret that you want to attach the resource-based policy. You can specify either the ARN or the friendly name of the secret.  If you specify an ARN, we generally recommend that you specify a complete ARN. You can specify a partial ARN too—for example, if you don’t include the final hyphen and six random characters that Secrets Manager adds at the end of the ARN when you created the secret. A partial ARN match can work as long as it uniquely matches only one secret. However, if your secret has a name that ends in a hyphen followed by six characters (before Secrets Manager adds the hyphen and six characters to the ARN) and you try to use that as a partial ARN, then those characters cause Secrets Manager to assume that you’re specifying a complete ARN. This confusion can cause unexpected results. To avoid this situation, we recommend that you don’t create secret names ending with a hyphen followed by six characters. If you specify an incomplete ARN without the random suffix, and instead provide the 'friendly name', you must not include the random suffix. If you do include the random suffix added by Secrets Manager, you receive either a ResourceNotFoundException or an AccessDeniedException error, depending on your permissions. .
        resource_policy(str): A JSON-formatted string constructed according to the grammar and syntax for an Amazon Web Services resource-based policy. The policy in the string identifies who can access or manage this secret and its versions. For information on how to format a JSON parameter for the various command line tool environments, see Using JSON for Parameters in the CLI User Guide.
        block_public_policy(bool, optional): (Optional) If you set the parameter, BlockPublicPolicy to true, then you block resource-based policies that allow broad access to the secret. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.secretsmanager.resource.policy.put(
                ctx, secret_id=value, resource_policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.secretsmanager.resource.policy.put secret_id=value, resource_policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="secretsmanager",
        operation="put_resource_policy",
        op_kwargs={
            "SecretId": secret_id,
            "ResourcePolicy": resource_policy,
            "BlockPublicPolicy": block_public_policy,
        },
    )


async def validate(hub, ctx, resource_policy: str, secret_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Validates that the resource policy does not grant a wide range of IAM principals access to your secret. The JSON request string input and response output displays formatted code with white space and line breaks for better readability. Submit your input as a single line JSON string. A resource-based policy is optional for secrets. The API performs three checks when validating the secret:   Sends a call to Zelkova, an automated reasoning engine, to ensure your Resource Policy does not allow broad access to your secret.   Checks for correct syntax in a policy.   Verifies the policy does not lock out a caller.    Minimum Permissions  You must have the permissions required to access the following APIs:    secretsmanager:PutResourcePolicy     secretsmanager:ValidateResourcePolicy

    Args:
        secret_id(str, optional):  (Optional) The identifier of the secret with the resource-based policy you want to validate. You can specify either the Amazon Resource Name (ARN) or the friendly name of the secret.  If you specify an ARN, we generally recommend that you specify a complete ARN. You can specify a partial ARN too—for example, if you don’t include the final hyphen and six random characters that Secrets Manager adds at the end of the ARN when you created the secret. A partial ARN match can work as long as it uniquely matches only one secret. However, if your secret has a name that ends in a hyphen followed by six characters (before Secrets Manager adds the hyphen and six characters to the ARN) and you try to use that as a partial ARN, then those characters cause Secrets Manager to assume that you’re specifying a complete ARN. This confusion can cause unexpected results. To avoid this situation, we recommend that you don’t create secret names ending with a hyphen followed by six characters. If you specify an incomplete ARN without the random suffix, and instead provide the 'friendly name', you must not include the random suffix. If you do include the random suffix added by Secrets Manager, you receive either a ResourceNotFoundException or an AccessDeniedException error, depending on your permissions. . Defaults to None.
        resource_policy(str): A JSON-formatted string constructed according to the grammar and syntax for an Amazon Web Services resource-based policy. The policy in the string identifies who can access or manage this secret and its versions. For information on how to format a JSON parameter for the various command line tool environments, see Using JSON for Parameters in the CLI User Guide.publi.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.secretsmanager.resource.policy.validate(
                ctx, resource_policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.secretsmanager.resource.policy.validate resource_policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="secretsmanager",
        operation="validate_resource_policy",
        op_kwargs={"SecretId": secret_id, "ResourcePolicy": resource_policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    document_id: str,
    authentication_token: str = None,
    limit: int = None,
    fields: str = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the path information (the hierarchy from the root folder) for the requested document. By default, Amazon WorkDocs returns a maximum of 100 levels upwards from the requested document and only includes the IDs of the parent folders in the path. You can limit the maximum number of levels. You can also request the names of the parent folders.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        document_id(str): The ID of the document.
        limit(int, optional): The maximum number of levels in the hierarchy to return. Defaults to None.
        fields(str, optional): A comma-separated list of values. Specify NAME to include the names of the parent folders. Defaults to None.
        marker(str, optional): This value is not supported. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.document.path.get(ctx, document_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.document.path.get document_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="get_document_path",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "DocumentId": document_id,
            "Limit": limit,
            "Fields": fields,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    service_name: str,
    source_configuration: Dict,
    instance_configuration: Dict = None,
    tags: List = None,
    encryption_configuration: Dict = None,
    health_check_configuration: Dict = None,
    auto_scaling_configuration_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create an AWS App Runner service. After the service is created, the action also automatically starts a deployment. This is an asynchronous operation. On a successful call, you can use the returned OperationId and the ListOperations call to track the operation's progress.

    Args:
        service_name(str): A name for the new service. It must be unique across all the running App Runner services in your AWS account in the AWS Region.
        source_configuration(Dict): The source to deploy to the App Runner service. It can be a code or an image repository.
        instance_configuration(Dict, optional): The runtime configuration of instances (scaling units) of the App Runner service. Defaults to None.
        tags(List, optional): An optional list of metadata items that you can associate with your service resource. A tag is a key-value pair. Defaults to None.
        encryption_configuration(Dict, optional): An optional custom encryption key that App Runner uses to encrypt the copy of your source repository that it maintains and your service logs. By default, App Runner uses an AWS managed CMK. Defaults to None.
        health_check_configuration(Dict, optional): The settings for the health check that AWS App Runner performs to monitor the health of your service. Defaults to None.
        auto_scaling_configuration_arn(str, optional): The Amazon Resource Name (ARN) of an App Runner automatic scaling configuration resource that you want to associate with your service. If not provided, App Runner associates the latest revision of a default auto scaling configuration. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.service.create(
                ctx, service_name=value, source_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.service.create service_name=value, source_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="create_service",
        op_kwargs={
            "ServiceName": service_name,
            "SourceConfiguration": source_configuration,
            "InstanceConfiguration": instance_configuration,
            "Tags": tags,
            "EncryptionConfiguration": encryption_configuration,
            "HealthCheckConfiguration": health_check_configuration,
            "AutoScalingConfigurationArn": auto_scaling_configuration_arn,
        },
    )


async def delete(hub, ctx, service_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete an AWS App Runner service. This is an asynchronous operation. On a successful call, you can use the returned OperationId and the ListOperations call to track the operation's progress.

    Args:
        service_arn(str): The Amazon Resource Name (ARN) of the App Runner service that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.service.delete(ctx, service_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.service.delete service_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="delete_service",
        op_kwargs={"ServiceArn": service_arn},
    )


async def describe(hub, ctx, service_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Return a full description of an AWS App Runner service.

    Args:
        service_arn(str): The Amazon Resource Name (ARN) of the App Runner service that you want a description for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.service.describe(ctx, service_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.service.describe service_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="describe_service",
        op_kwargs={"ServiceArn": service_arn},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of running AWS App Runner services in your AWS account.

    Args:
        next_token(str, optional): A token from a previous result page. Used for a paginated request. The request retrieves the next result page. All other parameter values must be identical to the ones specified in the initial request. If you don't specify NextToken, the request retrieves the first result page. Defaults to None.
        max_results(int, optional): The maximum number of results to include in each response (result page). It's used for a paginated request. If you don't specify MaxResults, the request retrieves all available results in a single response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.service.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.service.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="list_services",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def pause(hub, ctx, service_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Pause an active AWS App Runner service. App Runner reduces compute capacity for the service to zero and loses state (for example, ephemeral storage is removed). This is an asynchronous operation. On a successful call, you can use the returned OperationId and the ListOperations call to track the operation's progress.

    Args:
        service_arn(str): The Amazon Resource Name (ARN) of the App Runner service that you want to pause.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.service.pause(ctx, service_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.service.pause service_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="pause_service",
        op_kwargs={"ServiceArn": service_arn},
    )


async def resume(hub, ctx, service_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Resume an active AWS App Runner service. App Runner provisions compute capacity for the service. This is an asynchronous operation. On a successful call, you can use the returned OperationId and the ListOperations call to track the operation's progress.

    Args:
        service_arn(str): The Amazon Resource Name (ARN) of the App Runner service that you want to resume.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.service.resume(ctx, service_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.service.resume service_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="resume_service",
        op_kwargs={"ServiceArn": service_arn},
    )


async def update(
    hub,
    ctx,
    service_arn: str,
    source_configuration: Dict = None,
    instance_configuration: Dict = None,
    auto_scaling_configuration_arn: str = None,
    health_check_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update an AWS App Runner service. You can update the source configuration and instance configuration of the service. You can also update the ARN of the auto scaling configuration resource that's associated with the service. However, you can't change the name or the encryption configuration of the service. These can be set only when you create the service. To update the tags applied to your service, use the separate actions TagResource and UntagResource. This is an asynchronous operation. On a successful call, you can use the returned OperationId and the ListOperations call to track the operation's progress.

    Args:
        service_arn(str): The Amazon Resource Name (ARN) of the App Runner service that you want to update.
        source_configuration(Dict, optional): The source configuration to apply to the App Runner service. You can change the configuration of the code or image repository that the service uses. However, you can't switch from code to image or the other way around. This means that you must provide the same structure member of SourceConfiguration that you originally included when you created the service. Specifically, you can include either CodeRepository or ImageRepository. To update the source configuration, set the values to members of the structure that you include. Defaults to None.
        instance_configuration(Dict, optional): The runtime configuration to apply to instances (scaling units) of the App Runner service. Defaults to None.
        auto_scaling_configuration_arn(str, optional): The Amazon Resource Name (ARN) of an App Runner automatic scaling configuration resource that you want to associate with your service. Defaults to None.
        health_check_configuration(Dict, optional): The settings for the health check that AWS App Runner performs to monitor the health of your service. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.service.update(ctx, service_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.service.update service_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="update_service",
        op_kwargs={
            "ServiceArn": service_arn,
            "SourceConfiguration": source_configuration,
            "InstanceConfiguration": instance_configuration,
            "AutoScalingConfigurationArn": auto_scaling_configuration_arn,
            "HealthCheckConfiguration": health_check_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    progress_update_stream: str,
    migration_task_name: str,
    discovered_resource: Dict,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a discovered resource ID from Application Discovery Service with a migration task.

    Args:
        progress_update_stream(str): The name of the ProgressUpdateStream.
        migration_task_name(str): The identifier given to the MigrationTask. Do not store personal data in this field. .
        discovered_resource(Dict): Object representing a Resource.
        dry_run(bool, optional): Optional boolean flag to indicate whether any effect should take place. Used to test if the caller has permission to make the call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgh.discovered_resource.associate(
                ctx,
                progress_update_stream=value,
                migration_task_name=value,
                discovered_resource=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgh.discovered_resource.associate progress_update_stream=value, migration_task_name=value, discovered_resource=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgh",
        operation="associate_discovered_resource",
        op_kwargs={
            "ProgressUpdateStream": progress_update_stream,
            "MigrationTaskName": migration_task_name,
            "DiscoveredResource": discovered_resource,
            "DryRun": dry_run,
        },
    )


async def disassociate(
    hub,
    ctx,
    progress_update_stream: str,
    migration_task_name: str,
    configuration_id: str,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociate an Application Discovery Service discovered resource from a migration task.

    Args:
        progress_update_stream(str): The name of the ProgressUpdateStream.
        migration_task_name(str): The identifier given to the MigrationTask. Do not store personal data in this field. .
        configuration_id(str): ConfigurationId of the Application Discovery Service resource to be disassociated.
        dry_run(bool, optional): Optional boolean flag to indicate whether any effect should take place. Used to test if the caller has permission to make the call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgh.discovered_resource.disassociate(
                ctx, progress_update_stream=value, migration_task_name=value, configuration_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgh.discovered_resource.disassociate progress_update_stream=value, migration_task_name=value, configuration_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgh",
        operation="disassociate_discovered_resource",
        op_kwargs={
            "ProgressUpdateStream": progress_update_stream,
            "MigrationTaskName": migration_task_name,
            "ConfigurationId": configuration_id,
            "DryRun": dry_run,
        },
    )


async def list_all(
    hub,
    ctx,
    progress_update_stream: str,
    migration_task_name: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists discovered resources associated with the given MigrationTask.

    Args:
        progress_update_stream(str): The name of the ProgressUpdateStream.
        migration_task_name(str): The name of the MigrationTask. Do not store personal data in this field. .
        next_token(str, optional): If a NextToken was returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in NextToken. Defaults to None.
        max_results(int, optional): The maximum number of results returned per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgh.discovered_resource.list_all(
                ctx, progress_update_stream=value, migration_task_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgh.discovered_resource.list_all progress_update_stream=value, migration_task_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgh",
        operation="list_discovered_resources",
        op_kwargs={
            "ProgressUpdateStream": progress_update_stream,
            "MigrationTaskName": migration_task_name,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, file_share_arn: str, force_delete: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a file share from an S3 File Gateway. This operation is only supported for S3 File Gateways.

    Args:
        file_share_arn(str): The Amazon Resource Name (ARN) of the file share to be deleted.
        force_delete(bool, optional): If this value is set to true, the operation deletes a file share immediately and aborts all data uploads to Amazon Web Services. Otherwise, the file share is not deleted until all data is uploaded to Amazon Web Services. This process aborts the data upload process, and the file share enters the FORCE_DELETING status. Valid Values: true | false . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.file.share.delete(ctx, file_share_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.file.share.delete file_share_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="delete_file_share",
        op_kwargs={"FileShareARN": file_share_arn, "ForceDelete": force_delete},
    )


async def list_all(
    hub, ctx, gateway_arn: str = None, limit: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of the file shares for a specific S3 File Gateway, or the list of file shares that belong to the calling user account. This operation is only supported for S3 File Gateways.

    Args:
        gateway_arn(str, optional): The Amazon Resource Name (ARN) of the gateway whose file shares you want to list. If this field is not present, all file shares under your account are listed. Defaults to None.
        limit(int, optional): The maximum number of file shares to return in the response. The value must be an integer with a value greater than zero. Optional. Defaults to None.
        marker(str, optional): Opaque pagination token returned from a previous ListFileShares operation. If present, Marker specifies where to continue the list from after a previous call to ListFileShares. Optional. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.file.share.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.file.share.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="list_file_shares",
        op_kwargs={"GatewayARN": gateway_arn, "Limit": limit, "Marker": marker},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, name: str, platform: str, attributes: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates a platform application object for one of the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging), to which devices and mobile apps may register. You must specify PlatformPrincipal and PlatformCredential attributes when using the CreatePlatformApplication action.  PlatformPrincipal and PlatformCredential are received from the notification service.   For ADM, PlatformPrincipal is client id and PlatformCredential is client secret.   For Baidu, PlatformPrincipal is API key and PlatformCredential is secret key.   For APNS and APNS_SANDBOX, PlatformPrincipal is SSL certificate and PlatformCredential is private key.   For GCM (Firebase Cloud Messaging), there is no PlatformPrincipal and the PlatformCredential is API key.   For MPNS, PlatformPrincipal is TLS certificate and PlatformCredential is private key.   For WNS, PlatformPrincipal is Package Security Identifier and PlatformCredential is secret key.   You can use the returned PlatformApplicationArn as an attribute for the CreatePlatformEndpoint action.

    Args:
        name(str): Application names must be made up of only uppercase and lowercase ASCII letters, numbers, underscores, hyphens, and periods, and must be between 1 and 256 characters long.
        platform(str): The following platforms are supported: ADM (Amazon Device Messaging), APNS (Apple Push Notification Service), APNS_SANDBOX, and GCM (Firebase Cloud Messaging).
        attributes(Dict): For a list of attributes, see SetPlatformApplicationAttributes.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.platform.application.init.create(
                ctx, name=value, platform=value, attributes=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.platform.application.init.create name=value, platform=value, attributes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="create_platform_application",
        op_kwargs={"Name": name, "Platform": platform, "Attributes": attributes},
    )


async def delete(hub, ctx, platform_application_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a platform application object for one of the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging). For more information, see Using Amazon SNS Mobile Push Notifications.

    Args:
        platform_application_arn(str): PlatformApplicationArn of platform application object to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.platform.application.init.delete(
                ctx, platform_application_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.platform.application.init.delete platform_application_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="delete_platform_application",
        op_kwargs={"PlatformApplicationArn": platform_application_arn},
    )


async def list_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the platform application objects for the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging). The results for ListPlatformApplications are paginated and return a limited list of applications, up to 100. If additional records are available after the first page results, then a NextToken string will be returned. To receive the next page, you call ListPlatformApplications using the NextToken string received from the previous call. When there are no more records to return, NextToken will be null. For more information, see Using Amazon SNS Mobile Push Notifications.  This action is throttled at 15 transactions per second (TPS).

    Args:
        next_token(str, optional): NextToken string is used when calling ListPlatformApplications action to retrieve additional records that are available after the first page results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.platform.application.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.platform.application.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="list_platform_applications",
        op_kwargs={"NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    This method is deprecated. Instead, use GetAdministratorAccount. The Security Hub console continues to use GetMasterAccount. It will eventually change to use GetAdministratorAccount. Any IAM policies that specifically control access to this function must continue to use GetMasterAccount. You should also add GetAdministratorAccount to your policies to ensure that the correct permissions are in place after the console begins to use GetAdministratorAccount. Provides the details for the Security Hub administrator account for the current member account. Can be used by both member accounts that are managed using Organizations and accounts that were invited manually.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.master_account.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.master_account.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="securityhub", operation="get_master_account", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, role_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Associates a role with your account. AWS IoT Greengrass will use the role to access your Lambda functions and AWS IoT resources. This is necessary for deployments to succeed. The role must have at least minimum permissions in the policy ''AWSGreengrassResourceAccessRolePolicy''.

    Args:
        role_arn(str): The ARN of the service role you wish to associate with your account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.service_role.to_account.associate(
                ctx, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.service_role.to_account.associate role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="associate_service_role_to_account",
        op_kwargs={"RoleArn": role_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def restore(
    hub,
    ctx,
    db_cluster_identifier: str,
    source_db_cluster_identifier: str,
    restore_to_time: str = None,
    use_latest_restorable_time: bool = None,
    port: int = None,
    db_subnet_group_name: str = None,
    vpc_security_group_ids: List = None,
    tags: List = None,
    kms_key_id: str = None,
    enable_cloudwatch_logs_exports: List = None,
    deletion_protection: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Restores a cluster to an arbitrary point in time. Users can restore to any point in time before LatestRestorableTime for up to BackupRetentionPeriod days. The target cluster is created from the source cluster with the same configuration as the original cluster, except that the new cluster is created with the default security group.

    Args:
        db_cluster_identifier(str): The name of the new cluster to be created. Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens.   The first character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.  .
        source_db_cluster_identifier(str): The identifier of the source cluster from which to restore. Constraints:   Must match the identifier of an existing DBCluster.  .
        restore_to_time(str, optional): The date and time to restore the cluster to. Valid values: A time in Universal Coordinated Time (UTC) format. Constraints:   Must be before the latest restorable time for the instance.   Must be specified if the UseLatestRestorableTime parameter is not provided.   Cannot be specified if the UseLatestRestorableTime parameter is true.   Cannot be specified if the RestoreType parameter is copy-on-write.   Example: 2015-03-07T23:45:00Z . Defaults to None.
        use_latest_restorable_time(bool, optional): A value that is set to true to restore the cluster to the latest restorable backup time, and false otherwise.  Default: false  Constraints: Cannot be specified if the RestoreToTime parameter is provided. Defaults to None.
        port(int, optional): The port number on which the new cluster accepts connections. Constraints: Must be a value from 1150 to 65535.  Default: The default port for the engine. Defaults to None.
        db_subnet_group_name(str, optional): The subnet group name to use for the new cluster. Constraints: If provided, must match the name of an existing DBSubnetGroup. Example: mySubnetgroup . Defaults to None.
        vpc_security_group_ids(List, optional): A list of VPC security groups that the new cluster belongs to. Defaults to None.
        tags(List, optional): The tags to be assigned to the restored cluster. Defaults to None.
        kms_key_id(str, optional): The KMS key identifier to use when restoring an encrypted cluster from an encrypted cluster. The KMS key identifier is the Amazon Resource Name (ARN) for the KMS encryption key. If you are restoring a cluster with the same account that owns the KMS encryption key used to encrypt the new cluster, then you can use the KMS key alias instead of the ARN for the KMS encryption key. You can restore to a new cluster and encrypt the new cluster with an KMS key that is different from the KMS key used to encrypt the source cluster. The new DB cluster is encrypted with the KMS key identified by the KmsKeyId parameter. If you do not specify a value for the KmsKeyId parameter, then the following occurs:   If the cluster is encrypted, then the restored cluster is encrypted using the KMS key that was used to encrypt the source cluster.   If the cluster is not encrypted, then the restored cluster is not encrypted.   If DBClusterIdentifier refers to a cluster that is not encrypted, then the restore request is rejected. Defaults to None.
        enable_cloudwatch_logs_exports(List, optional): A list of log types that must be enabled for exporting to Amazon CloudWatch Logs. Defaults to None.
        deletion_protection(bool, optional): Specifies whether this cluster can be deleted. If DeletionProtection is enabled, the cluster cannot be deleted unless it is modified and DeletionProtection is disabled. DeletionProtection protects clusters from being accidentally deleted. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.cluster.to_point_in_time.restore(
                ctx, db_cluster_identifier=value, source_db_cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.cluster.to_point_in_time.restore db_cluster_identifier=value, source_db_cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="restore_db_cluster_to_point_in_time",
        op_kwargs={
            "DBClusterIdentifier": db_cluster_identifier,
            "SourceDBClusterIdentifier": source_db_cluster_identifier,
            "RestoreToTime": restore_to_time,
            "UseLatestRestorableTime": use_latest_restorable_time,
            "Port": port,
            "DBSubnetGroupName": db_subnet_group_name,
            "VpcSecurityGroupIds": vpc_security_group_ids,
            "Tags": tags,
            "KmsKeyId": kms_key_id,
            "EnableCloudwatchLogsExports": enable_cloudwatch_logs_exports,
            "DeletionProtection": deletion_protection,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, task_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels a mitigation action task that is in progress. If the task is not in progress, an InvalidRequestException occurs.

    Args:
        task_id(str): The unique identifier for the task that you want to cancel. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.audit.mitigation_action.task.cancel(ctx, task_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.audit.mitigation_action.task.cancel task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="cancel_audit_mitigation_actions_task",
        op_kwargs={"taskId": task_id},
    )


async def describe(hub, ctx, task_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about an audit mitigation task that is used to apply mitigation actions to a set of audit findings. Properties include the actions being applied, the audit checks to which they're being applied, the task status, and aggregated task statistics.

    Args:
        task_id(str): The unique identifier for the audit mitigation task.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.audit.mitigation_action.task.describe(ctx, task_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.audit.mitigation_action.task.describe task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_audit_mitigation_actions_task",
        op_kwargs={"taskId": task_id},
    )


async def list_all(
    hub,
    ctx,
    start_time: str,
    end_time: str,
    audit_task_id: str = None,
    finding_id: str = None,
    task_status: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of audit mitigation action tasks that match the specified filters.

    Args:
        audit_task_id(str, optional): Specify this filter to limit results to tasks that were applied to results for a specific audit. Defaults to None.
        finding_id(str, optional): Specify this filter to limit results to tasks that were applied to a specific audit finding. Defaults to None.
        task_status(str, optional): Specify this filter to limit results to tasks that are in a specific state. Defaults to None.
        max_results(int, optional): The maximum number of results to return at one time. The default is 25. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.
        start_time(str): Specify this filter to limit results to tasks that began on or after a specific date and time.
        end_time(str): Specify this filter to limit results to tasks that were completed or canceled on or before a specific date and time.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.audit.mitigation_action.task.list_all(
                ctx, start_time=value, end_time=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.audit.mitigation_action.task.list_all start_time=value, end_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_audit_mitigation_actions_tasks",
        op_kwargs={
            "auditTaskId": audit_task_id,
            "findingId": finding_id,
            "taskStatus": task_status,
            "maxResults": max_results,
            "nextToken": next_token,
            "startTime": start_time,
            "endTime": end_time,
        },
    )


async def start(
    hub,
    ctx,
    task_id: str,
    target: Dict,
    audit_check_to_actions_mapping: Dict,
    client_request_token: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a task that applies a set of mitigation actions to the specified target.

    Args:
        task_id(str): A unique identifier for the task. You can use this identifier to check the status of the task or to cancel it.
        target(Dict): Specifies the audit findings to which the mitigation actions are applied. You can apply them to a type of audit check, to all findings from an audit, or to a specific set of findings.
        audit_check_to_actions_mapping(Dict): For an audit check, specifies which mitigation actions to apply. Those actions must be defined in your AWS account.
        client_request_token(str): Each audit mitigation task must have a unique client request token. If you try to start a new task with the same token as a task that already exists, an exception occurs. If you omit this value, a unique client request token is generated automatically.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.audit.mitigation_action.task.start(
                ctx,
                task_id=value,
                target=value,
                audit_check_to_actions_mapping=value,
                client_request_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.audit.mitigation_action.task.start task_id=value, target=value, audit_check_to_actions_mapping=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="start_audit_mitigation_actions_task",
        op_kwargs={
            "taskId": task_id,
            "target": target,
            "auditCheckToActionsMapping": audit_check_to_actions_mapping,
            "clientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    cluster_name: str,
    nodegroup_name: str,
    labels: Dict = None,
    taints: Dict = None,
    scaling_config: Dict = None,
    update_config: Dict = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an Amazon EKS managed node group configuration. Your node group continues to function during the update. The response output includes an update ID that you can use to track the status of your node group update with the DescribeUpdate API operation. Currently you can update the Kubernetes labels for a node group or the scaling configuration.

    Args:
        cluster_name(str): The name of the Amazon EKS cluster that the managed node group resides in.
        nodegroup_name(str): The name of the managed node group to update.
        labels(Dict, optional): The Kubernetes labels to be applied to the nodes in the node group after the update. Defaults to None.
        taints(Dict, optional): The Kubernetes taints to be applied to the nodes in the node group after the update. Defaults to None.
        scaling_config(Dict, optional): The scaling configuration details for the Auto Scaling group after the update. Defaults to None.
        update_config(Dict, optional): The node group update configuration. Defaults to None.
        client_request_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.nodegroup.config.update(
                ctx, cluster_name=value, nodegroup_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.nodegroup.config.update cluster_name=value, nodegroup_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="update_nodegroup_config",
        op_kwargs={
            "clusterName": cluster_name,
            "nodegroupName": nodegroup_name,
            "labels": labels,
            "taints": taints,
            "scalingConfig": scaling_config,
            "updateConfig": update_config,
            "clientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    data_source_id: str,
    data_spec: Dict,
    role_arn: str,
    data_source_name: str = None,
    compute_statistics: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a DataSource from a database hosted on an Amazon Redshift cluster. A DataSource references data that can be used to perform either CreateMLModel, CreateEvaluation, or CreateBatchPrediction operations.  CreateDataSourceFromRedshift is an asynchronous operation. In response to CreateDataSourceFromRedshift, Amazon Machine Learning (Amazon ML) immediately returns and sets the DataSource status to PENDING. After the DataSource is created and ready for use, Amazon ML sets the Status parameter to COMPLETED. DataSource in COMPLETED or PENDING states can be used to perform only CreateMLModel, CreateEvaluation, or CreateBatchPrediction operations.   If Amazon ML can't accept the input source, it sets the Status parameter to FAILED and includes an error message in the Message attribute of the GetDataSource operation response.  The observations should be contained in the database hosted on an Amazon Redshift cluster and should be specified by a SelectSqlQuery query. Amazon ML executes an Unload command in Amazon Redshift to transfer the result set of the SelectSqlQuery query to S3StagingLocation. After the DataSource has been created, it's ready for use in evaluations and batch predictions. If you plan to use the DataSource to train an MLModel, the DataSource also requires a recipe. A recipe describes how each input variable will be used in training an MLModel. Will the variable be included or excluded from training? Will the variable be manipulated; for example, will it be combined with another variable or will it be split apart into word combinations? The recipe provides answers to these questions. You can't change an existing datasource, but you can copy and modify the settings from an existing Amazon Redshift datasource to create a new datasource. To do so, call GetDataSource for an existing datasource and copy the values to a CreateDataSource call. Change the settings that you want to change and make sure that all required fields have the appropriate values.

    Args:
        data_source_id(str): A user-supplied ID that uniquely identifies the DataSource.
        data_source_name(str, optional): A user-supplied name or description of the DataSource. . Defaults to None.
        data_spec(Dict): The data specification of an Amazon Redshift DataSource:   DatabaseInformation -    DatabaseName - The name of the Amazon Redshift database.     ClusterIdentifier - The unique ID for the Amazon Redshift cluster.     DatabaseCredentials - The AWS Identity and Access Management (IAM) credentials that are used to connect to the Amazon Redshift database.   SelectSqlQuery - The query that is used to retrieve the observation data for the Datasource.   S3StagingLocation - The Amazon Simple Storage Service (Amazon S3) location for staging Amazon Redshift data. The data retrieved from Amazon Redshift using the SelectSqlQuery query is stored in this location.   DataSchemaUri - The Amazon S3 location of the DataSchema.   DataSchema - A JSON string representing the schema. This is not required if DataSchemaUri is specified.    DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the DataSource.  Sample -  "{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"   .
        role_arn(str): A fully specified role Amazon Resource Name (ARN). Amazon ML assumes the role on behalf of the user to create the following:   A security group to allow Amazon ML to execute the SelectSqlQuery query on an Amazon Redshift cluster   An Amazon S3 bucket policy to grant Amazon ML read/write permissions on the S3StagingLocation   .
        compute_statistics(bool, optional): The compute statistics for a DataSource. The statistics are generated from the observation data referenced by a DataSource. Amazon ML uses the statistics internally during MLModel training. This parameter must be set to true if the DataSource needs to be used for MLModel training. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.data_source.from_.redshift.create(
                ctx, data_source_id=value, data_spec=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.data_source.from_.redshift.create data_source_id=value, data_spec=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="create_data_source_from_redshift",
        op_kwargs={
            "DataSourceId": data_source_id,
            "DataSourceName": data_source_name,
            "DataSpec": data_spec,
            "RoleARN": role_arn,
            "ComputeStatistics": compute_statistics,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, set_as_active: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a 2048-bit RSA key pair and issues an X.509 certificate using the issued public key. You can also call CreateKeysAndCertificate over MQTT from a device, for more information, see Provisioning MQTT API.  Note This is the only time AWS IoT issues the private key for this certificate, so it is important to keep it in a secure location.

    Args:
        set_as_active(bool, optional): Specifies whether the certificate is active. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.keys_and_certificate.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.keys_and_certificate.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_keys_and_certificate",
        op_kwargs={"setAsActive": set_as_active},
    )
